<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_Faq
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.Pinpoint.co.uk)
 * @author      Ahmed Goda <hello@Pinpoint.co.uk>
 */

namespace Pinpoint\Faq\Block\Adminhtml\Faq\Edit;

use Magento\Backend\Block\Widget\Context;
use Magento\Framework\Exception\NoSuchEntityException;
use Pinpoint\Faq\Api\Data\FaqInterface;
use Pinpoint\Faq\Api\FaqRepositoryInterface;
use Magento\Framework\View\Element\Template;

/**
 * Class Product
 */
class Product extends Template
{
    /**
     * @var Context
     */
    protected $context;

    /**
     * @var FaqRepositoryInterface
     */
    protected $faqRepository;

    /**
    * @var \Magento\Store\Model\StoreManagerInterface
    */
    protected $storeManager;

    /**
     * Catalog product model
     *
     * @var \Magento\Catalog\Api\ProductRepositoryInterface
     */
    protected $productRepository;

    /**
     * @param Context $context
     * @param FaqRepositoryInterface $faqRepository
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Catalog\Api\ProductRepositoryInterface $productRepository
     */
    public function __construct(
        Context $context,
        FaqRepositoryInterface $faqRepository,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Catalog\Api\ProductRepositoryInterface $productRepository,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->context            = $context;
        $this->faqRepository      = $faqRepository;
        $this->storeManager       = $storeManager;
        $this->productRepository  = $productRepository;
    }

    /**
     * Return the id of the selected item
     *
     * @return int|null
     */
    public function getItemId(): ?int
    {
        try {
            $faq = $this->faqRepository->getById(
                $this->context->getRequest()->getParam(FaqInterface::FAQ_ID, 0)
            );
            if ($faq instanceof FaqInterface) {
                return $faq->getId();
            }
        } catch (NoSuchEntityException $e) {
        }
        return null;
    }

    /**
     * Retrieve current product model
     *
     * @return \Magento\Catalog\Model\Product
     * @throws NoSuchEntityException
     */
    public function getProduct()
    {
        $faq = $this->faqRepository->getById($this->getItemId());

        return $this->productRepository->getById($faq->getProductId(), false, $this->storeManager->getStore()->getId());
    }
}