<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_Faq
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.Pinpoint.co.uk)
 * @author      Ahmed Goda <hello@Pinpoint.co.uk>
 */

namespace Pinpoint\Faq\Model;

use Pinpoint\Faq\Api\Data\FaqInterface;
use Pinpoint\Faq\Api\FaqRepositoryInterface;
use Pinpoint\Faq\Model\ResourceModel\Faq\CollectionFactory;

/**
 * Class FaqRepository
 */
class FaqRepository implements FaqRepositoryInterface
{
    /**
     * FaqRepository constructor
     *
     * @param CollectionFactory $collectionFactory
     */
    public function __construct(CollectionFactory $collectionFactory)
    {
        $this->collectionFactory = $collectionFactory;
    }

    /**
     * @param int $id
     * @return FaqInterface|null
     */
    public function getById(int $id): ?FaqInterface
    {
        return $this->collectionFactory->create()->getItemById($id);
    }

    /**
     * @return FaqInterface[]
     */
    public function getList(): array
    {
        return $this->collectionFactory
            ->create()
            ->setOrder(FaqInterface::CREATED_AT, 'DESC')
            ->getItems();
    }

    /**
     * @param int $id
     * @return FaqInterface[]
     */
    public function getItemsByProductId(int $id)
    {
        return $this
            ->collectionFactory
            ->create()
            ->setOrder(FaqInterface::CREATED_AT, 'DESC')
            ->addFieldToFilter(FaqInterface::PRODUCT_ID, ['eq' => $id])
            ->getItems();
    }

    /**
     * @param array $ids
     * @return FaqInterface[]
     */
    public function getActiveItemsByIds(array $ids)
    {
        return $this
            ->collectionFactory
            ->create()
            ->setOrder(FaqInterface::CREATED_AT, 'DESC')
            ->addFieldToFilter(FaqInterface::FAQ_ID, ['in' => $ids])
            ->addFieldToFilter(FaqInterface::IS_ACTIVE, ['eq' => FaqInterface::ACTIVE])
            ->getItems();
    }
}
